#!/bin/bash
# packager          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# package	    : bareftp
# homepage          : http://www.bareftp.org/
# source locatio    : http://www.bareftp.org/release/bareftp-0.3.7.tar.gz
# dependency        : Mono, Gtk# (gtk-sharp), Gnome# (gnome-sharp) 

softname='bareftp'
softversion='0.3.7'
packageversion='66.1'

arch='i686'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://www.bareftp.org/release/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
       |-----handy-ruler------------------------------------------------------|
bareftp: bareftp - A File Transfer Client
bareftp:
bareftp: bareFTP supports the FTP, FTP over SSL/TLS (FTPS) and SSH File 
bareftp: Transfer Protocol (SFTP). It is written in C#, targeting the Mono 
bareftp: framework and the GNOME desktop environment.
bareftp:
bareftp:
bareftp:
bareftp:
bareftp:
bareftp:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code 
cd $buildir
tar xzvf $srcpkg
cd $src	

# building
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

export GNOME_KEYRING_SHARP_LIBS="/usr/lib/mono/gnome-keyring-sharp-1.0/Gnome.Keyring.dll"
export GNOME_KEYRING_SHARP_CFLAGS="-I:/usr/lib/mono/gnome-keyring-sharp-1.0/Gnome.Keyring.dll"

./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

make
make install DESTDIR=$dest

# add 'default' files
    cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING CREDITS ChangeLog INSTALL README \
      $dest/usr/doc/$softname-$softversion

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress Man pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# put the ZenWalk build in the right directory
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# .md5
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "mono,gnome-keyring-sharp,gnome-sharp,gtk-sharp2" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/bareftp/source/build-bareftp.sh > $package.src
echo $source >> $package.src

# erase src
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
